<?php

namespace Litecms\Loan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Loan\Models\Loan;

class LoanPolicy
{

    /**
     * Determine if the given user can view the loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function view(UserPolicy $user, Loan $loan)
    {
        if ($user->canDo('loan.loan.view') && $user->isAdmin()) {
            return true;
        }

        return $loan->user_id == user_id() && $loan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('loan.loan.create');
    }

    /**
     * Determine if the given user can update the given loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function update(UserPolicy $user, Loan $loan)
    {
        if ($user->canDo('loan.loan.edit') && $user->isAdmin()) {
            return true;
        }

        return $loan->user_id == user_id() && $loan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Loan $loan)
    {
        return $loan->user_id == user_id() && $loan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Loan $loan)
    {
        if ($user->canDo('loan.loan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given loan.
     *
     * @param UserPolicy $user
     * @param Loan $loan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Loan $loan)
    {
        if ($user->canDo('loan.loan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
